searchData={"items":[{"type":"module","title":"EredisSub","doc":"Publishes binary messages to Redis Pub/Sub channels.\nSubscribes to channels and calls a handler function when a message is received.","ref":"EredisSub.html"},{"type":"module","title":"Usage - EredisSub","doc":"","ref":"EredisSub.html#module-usage"},{"type":"module","title":"Publish - EredisSub","doc":"EredisSub.Server.publish(\"my_channel\", \"Hello, world!\")","ref":"EredisSub.html#module-publish"},{"type":"module","title":"Subscribe - EredisSub","doc":"Implement the behaviour to be called when a message is received:\n\n    defmodule MyModule do\n      @behaviour EredisSub.Handler\n\n      @impl EredisSub.Handler\n      def handle_pubsub_message(message, metadata) do\n        # Do something...\n      end\n    end\n\nSubscribe to a channel:\n\n    metadata_example = %{subscribed_at: DateTime.utc_now()}\n    EredisSub.Server.subscribe(\"my_channel\", MyModule, metadata_example)","ref":"EredisSub.html#module-subscribe"},{"type":"module","title":"Add the following to your supervision tree: - EredisSub","doc":"children = [\n      EredisSub\n    ]\n\nOptional configuration can be passed to `eredis` and `eredis_sub`, check [their docs](https://hexdocs.pm/eredis/readme.html#connect-a-client-start_link-1).","ref":"EredisSub.html#module-add-the-following-to-your-supervision-tree"},{"type":"function","title":"EredisSub.child_spec/1","doc":"","ref":"EredisSub.html#child_spec/1"},{"type":"function","title":"EredisSub.publish/2","doc":"Publish a message to a channel.\nIf successfull, returns the number of subscribers that received the message.\nIt should never error, unless there is a connection problem.","ref":"EredisSub.html#publish/2"},{"type":"function","title":"Examples - EredisSub.publish/2","doc":"iex> EredisSub.publish(\"my_channel\", \"Hello, world!\")\n    {:ok, 0}","ref":"EredisSub.html#publish/2-examples"},{"type":"function","title":"EredisSub.start_link/1","doc":"","ref":"EredisSub.html#start_link/1"},{"type":"function","title":"EredisSub.subscribe/3","doc":"Subscribe to a channel.","ref":"EredisSub.html#subscribe/3"},{"type":"function","title":"Examples - EredisSub.subscribe/3","doc":"iex> channel = \"my channel\"\n    ...> metadata = %{}\n    ...>\n    ...> defmodule FooBar do\n    ...>   def handle_pubsub_message(_message, _metadata) do\n    ...>     # Do something...\n    ...>   end\n    ...> end\n    ...>\n    ...> EredisSub.subscribe(channel, FooBar, metadata)\n    :ok","ref":"EredisSub.html#subscribe/3-examples"},{"type":"function","title":"EredisSub.unsubscribe_all/1","doc":"Unsubscribe all handlers from a channel.","ref":"EredisSub.html#unsubscribe_all/1"},{"type":"function","title":"Examples - EredisSub.unsubscribe_all/1","doc":"iex> EredisSub.unsubscribe_all(\"my_channel\")\n    :ok","ref":"EredisSub.html#unsubscribe_all/1-examples"},{"type":"behaviour","title":"EredisSub.Handler","doc":"Behaviour for handling messages received from Redis.","ref":"EredisSub.Handler.html"},{"type":"callback","title":"EredisSub.Handler.handle_pubsub_message/2","doc":"Handles a message received from Redis.\nReceives a binary message and a metadata that can be customized upon subscription.\nReturn value is ignored.","ref":"EredisSub.Handler.html#c:handle_pubsub_message/2"},{"type":"module","title":"EredisSub.Server","doc":"Holds internal state for `EredisSub`, which are: a connection to publish,\na connection to subscribe and a map of subscriptions.\n\nAlso, it converts Elixir strings to Erlang charlists used by `eredis`.\n\n**Do not use this module directly. Instead, use `EredisSub`.**","ref":"EredisSub.Server.html"},{"type":"function","title":"EredisSub.Server.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"EredisSub.Server.html#child_spec/1"},{"type":"function","title":"EredisSub.Server.init/1","doc":"","ref":"EredisSub.Server.html#init/1"},{"type":"function","title":"EredisSub.Server.publish/3","doc":"","ref":"EredisSub.Server.html#publish/3"},{"type":"function","title":"EredisSub.Server.start_link/2","doc":"","ref":"EredisSub.Server.html#start_link/2"},{"type":"function","title":"EredisSub.Server.subscribe/4","doc":"","ref":"EredisSub.Server.html#subscribe/4"},{"type":"function","title":"EredisSub.Server.unsubscribe_all/2","doc":"","ref":"EredisSub.Server.html#unsubscribe_all/2"},{"type":"extras","title":"README","doc":"![Elixir CI](https://github.com/loopsocial/eredis_sub/actions/workflows/elixir.yml/badge.svg)\n![Hex.pm Version](https://img.shields.io/hexpm/v/eredis_sub?color=blue)\n\n# EredisSub\n\nWraps [`eredis`](https://hexdocs.pm/eredis/) and [`eredis_sub`](https://github.com/Nordix/eredis/blob/master/src/eredis_sub.erl) functionallity for Elixir usage.\n\n- Publishes binary messages to Redis Pub/Sub channels.\n- Subscribes to channels and calls a handler function when a message is received.","ref":"readme.html"},{"type":"extras","title":"Usage - README","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Publish - README","doc":"```elixir\nEredisSub.publish(\"my_channel\", \"Hello, world!\")\n```","ref":"readme.html#publish"},{"type":"extras","title":"Subscribe - README","doc":"Implement the behaviour to be called when a message is received:\n\n```elixir\ndefmodule MyModule do\n  @behaviour EredisSub.Handler\n\n  @impl EredisSub.Handler\n  def handle_pubsub_message(message, metadata) do\n    # Do something...\n  end\nend\n```\n\nSubscribe to a channel:\n\n```elixir\nmetadata_example = %{subscribed_at: DateTime.utc_now()}\nEredisSub.subscribe(\"my_channel\", MyModule, metadata_example)\n```","ref":"readme.html#subscribe"},{"type":"extras","title":"Installation - README","doc":"```elixir\ndef deps do\n  [\n    {:eredis_sub, \"~> 0.1.0\"}\n  ]\nend\n```\n\nAdd the following to your supervision tree on `application.ex`:\n\n```elixir\nchildren = [\n  EredisSub\n]\n```\n\nOptional configuration can be passed to `eredis` and `eredis_sub`, check [their docs](https://hexdocs.pm/eredis/readme.html#connect-a-client-start_link-1):\n\n```elixir\nchildren = [\n  {EredisSub, [database: 2, username: \"foo\", password: \"bar\"]}\n]\n```","ref":"readme.html#installation"},{"type":"extras","title":"Motivations - README","doc":"","ref":"readme.html#motivations"},{"type":"extras","title":"Why not use `Phoenix.PubSub`? - README","doc":"Because multiple applications in many programming languages can use Redis Pub/Sub,\nbut they don't serialize their binary messages according to `Phoenix` schema.","ref":"readme.html#why-not-use-phoenix-pubsub"},{"type":"extras","title":"Why not use `eredis` directly? - README","doc":"That's also a great option. With `EredisSub` Elixir abstraction we intend to hide\nErlang specific knowledge, for example Erlang strings and OTP processes. We changed\nthe API to let clients subscribe a handler function to a Pub/Sub channel, similar\nto how [`:telemetry`](https://hexdocs.pm/telemetry/readme.html) attaches handlers.\n\nWe sacrificed flexibility on client process architecture, for a simpler mental model.\nIf you need to handle message passing or a pool of processes, for example to handle\nheavier loads, use [`eredis`](https://hexdocs.pm/eredis/) directly.","ref":"readme.html#why-not-use-eredis-directly"},{"type":"extras","title":"Why not use [`Redix`](https://hexdocs.pm/redix/Redix.html)? - README","doc":"Because it doesn't support Redis Cluster. Since our project already depends on\n`eredis_cluster` (thus also depends on `eredis`), we wanted to stick with it.","ref":"readme.html#why-not-use-redix-https-hexdocs-pm-redix-redix-html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}